aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/new_packet_list.h
diff options
context:
space:
mode:
Diffstat (limited to 'gtk/new_packet_list.h')
-rw-r--r--gtk/new_packet_list.h19
1 files changed, 13 insertions, 6 deletions
diff --git a/gtk/new_packet_list.h b/gtk/new_packet_list.h
index fbca9de3cf..bc9cddf979 100644
--- a/gtk/new_packet_list.h
+++ b/gtk/new_packet_list.h
@@ -67,19 +67,19 @@ extern void new_packet_list_set_font(PangoFontDescription *font);
*/
extern void new_packet_list_mark_frame_cb(GtkWidget *widget, gpointer data);
/** Mark all packets in the list.
*
* @param widget parent widget (unused)
* @param data unused
*/
-void new_packet_list_mark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_);
+extern void new_packet_list_mark_all_displayed_frames_cb(GtkWidget *w _U_, gpointer data _U_);
-/** Unmark all packets in the list.
+/** UnMark all packets in the capture.
*
* @param widget parent widget (unused)
* @param data unused
*/
-void new_packet_list_unmark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_);
+extern void new_packet_list_unmark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_);
/** Ignore the currently selected packet.
*
@@ -88,12 +88,12 @@ void new_packet_list_unmark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_);
*/
extern void new_packet_list_ignore_frame_cb(GtkWidget *widget, gpointer data);
/** Ignore all packets in the list.
*
* @param widget parent widget (unused)
* @param data unused
*/
-extern void new_packet_list_ignore_all_frames_cb(GtkWidget *w _U_, gpointer data _U_);
+extern void new_packet_list_ignore_all_displayed_frames_cb(GtkWidget *w _U_, gpointer data _U_);
/** Un-ignore all packets in the list.
*
@@ -102,6 +102,13 @@ extern void new_packet_list_ignore_all_frames_cb(GtkWidget *w _U_, gpointer data
*/
extern void new_packet_list_unignore_all_frames_cb(GtkWidget *w _U_, gpointer data _U_);
+/** Un-Time Reference all packets in the capture.
+ *
+ * @param widget parent widget (unused)
+ * @param data unused
+ */
+extern void new_packet_list_untime_reference_all_frames_cb(GtkWidget *w _U_, gpointer data _U_);
+
/* Different modes of copying summary data */
typedef enum {
CS_TEXT, /* Packet summary data (tab separated) */
@@ -67,19 +67,19 @@ extern void new_packet_list_set_font(PangoFontDescription *font);
*/
extern void new_packet_list_mark_frame_cb(GtkWidget *widget, gpointer data);
-/** Mark all packets in the list.
+/** Mark/unmark all displayed packets.
*
* @param widget parent widget (unused)
@@ -88,12 +88,12 @@ void new_packet_list_unmark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_);
*/
extern void new_packet_list_ignore_frame_cb(GtkWidget *widget, gpointer data);
-/** Ignore all packets in the list.
+/** Ignore/Unignore all displayed packets.
*
* @param widget parent widget (unused)